@@ -1,9 +1,6 @@
-#' @include reporter.R
-NULL
-
-#' Test reporter: stop on error.
+#' Test reporter: stop on error
 #'
-#' The default reporter, executed when `expect_that` is run interactively.
+#' The default reporter used when [expect_that()] is run interactively.
 #' It responds by [stop()]ping on failures and doing nothing otherwise. This
 #' will ensure that a failing test will raise an error.
 #'
@@ -17,30 +14,50 @@ StopReporter <- R6::R6Class("StopReporter",
   inherit = Reporter,
   public = list(
     failures = NULL,
+    n_fail = 0L,
+    stop_reporter = TRUE,
+    praise = TRUE,
 
-    initialize = function() {
+    initialize = function(stop_reporter = TRUE, praise = TRUE) {
       super$initialize()
       self$failures <- Stack$new()
+      self$praise <- praise
+      self$stop_reporter <- stop_reporter
+    },
+
+    start_test = function(context, test) {
+      self$failures <- Stack$new()
     },
 
-    end_test = function(context, test) {
-      failures <- self$failures$as_list()
-      if (length(failures) == 0) {
+    add_result = function(context, test, result) {
+      if (expectation_success(result)) {
         return()
       }
 
-      # reset failures for next test
-      self$failures$initialize()
+      if (expectation_broken(result)) {
+        self$n_fail <- self$n_fail + 1
+      }
 
-      messages <- vapply(failures, format, character(1))
-      messages <- paste0("* ", messages, collapse = "\n")
-
-      stop("Test failed: '", test, "'\n", messages, call. = FALSE)
+      self$failures$push(result)
     },
 
-    add_result = function(context, test, result) {
-      if (expectation_broken(result)) {
-        self$failures$push(result)
+    end_test = function(context, test) {
+      self$local_user_output()
+
+      failures <- self$failures$as_list()
+      if (length(failures) == 0 && self$praise) {
+        self$cat_line(colourise("Test passed", "success"), " ", praise_emoji())
+        return()
+      }
+
+      messages <- vapply(failures, issue_summary, rule = TRUE, character(1))
+      if (length(messages) > 0) {
+        self$cat_line(messages, "\n")
+      }
+    },
+    stop_if_needed = function() {
+      if (self$stop_reporter && self$n_fail > 0) {
+        abort("Test failed", call = NULL)
       }
     }
   )
