@@ -32,7 +32,7 @@ test_that("source_file always uses UTF-8 encoding", {
   }
 
   ## Try to read it in latin1 and UTF-8 locales
-  ## They have diffefent names on Unix and Windows
+  ## They have different names on Unix and Windows
   run_test("en_US.ISO8859-1")
   run_test("en_US.UTF-8")
   run_test("English_United States.1252")
@@ -45,3 +45,40 @@ test_that("source_file wraps error", {
     source_file(test_path("reporters/error-setup.R"), wrap = FALSE)
   })
 })
+
+
+# filter_label -------------------------------------------------------------
+
+test_that("can find only matching test", {
+  code <- exprs(
+    f(),
+    test_that("foo", {}),
+    g(),
+    test_that("bar", {}),
+    h()
+  )
+  expect_equal(filter_desc(code, "foo"), code[c(1, 2)])
+  expect_equal(filter_desc(code, "bar"), code[c(1, 3, 4)])
+  expect_snapshot(filter_desc(code, "baz"), error = TRUE)
+})
+
+test_that("preserve srcrefs", {
+  code <- parse(keep.source = TRUE, text = '
+    test_that("foo", {
+      # this is a comment
+    })
+  ')
+  expect_snapshot(filter_desc(code, "foo"))
+})
+
+
+test_that("errors if duplicate labels", {
+  code <- exprs(
+    f(),
+    test_that("baz", {}),
+    test_that("baz", {}),
+    g()
+  )
+
+  expect_snapshot(filter_desc(code, "baz"), error = TRUE)
+})
